@@ -15,10 +15,12 @@ module Rouge
 
       tag 'javascript'
       aliases 'js'
-      filenames '*.js', '*.mjs'
+      filenames '*.cjs', '*.js', '*.mjs'
       mimetypes 'application/javascript', 'application/x-javascript',
                 'text/javascript', 'text/x-javascript'
 
+      # Pseudo-documentation: https://stackoverflow.com/questions/1661197/what-characters-are-valid-for-javascript-variable-names
+
       def self.detect?(text)
         return 1 if text.shebang?('node')
         return 1 if text.shebang?('jsc')
@@ -73,7 +75,7 @@ module Rouge
       end
 
       state :regex_end do
-        rule %r/[gim]+/, Str::Regex, :pop!
+        rule %r/[gimuy]+/, Str::Regex, :pop!
         rule(//) { pop! }
       end
 
@@ -138,7 +140,7 @@ module Rouge
       end
 
       def self.id_regex
-        /[$a-z_][a-z0-9_]*/io
+        /[\p{L}\p{Nl}$_][\p{Word}]*/io
       end
 
       id = self.id_regex
@@ -147,7 +149,7 @@ module Rouge
         rule %r/\A\s*#!.*?\n/m, Comment::Preproc, :statement
         rule %r((?<=\n)(?=\s|/|<!--)), Text, :expr_start
         mixin :comments_and_whitespace
-        rule %r(\+\+ | -- | ~ | && | \|\| | \\(?=\n) | << | >>>? | ===
+        rule %r(\+\+ | -- | ~ | \?\?=? | && | \|\| | \\(?=\n) | << | >>>? | ===
                | !== )x,
           Operator, :expr_start
         rule %r([-<>+*%&|\^/!=]=?), Operator, :expr_start
@@ -160,6 +162,10 @@ module Rouge
           push :template_string
         end
 
+        # special case for the safe navigation operator ?.
+        # so that we don't start detecting a ternary expr
+        rule %r/[?][.]/, Punctuation
+
         rule %r/[?]/ do
           token Punctuation
           push :ternary
@@ -171,6 +177,28 @@ module Rouge
           push :expr_start
         end
 
+        rule %r/(class)((?:\s|\\\s)+)/ do
+          groups Keyword::Declaration, Text
+          push :classname
+        end
+
+        rule %r/([\p{Nl}$_]*\p{Lu}[\p{Word}]*)[ \t]*(?=(\(.*\)))/m, Name::Class
+
+        rule %r/(function)((?:\s|\\\s)+)(#{id})/ do
+          groups Keyword::Declaration, Text, Name::Function
+        end
+
+        rule %r/function(?=(\(.*\)))/, Keyword::Declaration # For anonymous functions
+
+        rule %r/(#{id})[ \t]*(?=(\(.*\)))/m do |m|
+          if self.class.keywords.include? m[1]
+            # "if" in "if (...)" or "switch" in "switch (...)" are recognized as keywords.
+            token Keyword
+          else
+            token Name::Function
+          end
+        end
+
         rule %r/[{}]/, Punctuation, :statement
 
         rule id do |m|
@@ -214,6 +242,14 @@ module Rouge
         rule %r/'/, Str::Delimiter, :pop!
       end
 
+      state :classname do
+        rule %r/(#{id})((?:\s|\\\s)+)(extends)((?:\s|\\\s)+)/ do
+          groups Name::Class, Text, Keyword::Declaration, Text
+        end
+
+        rule id, Name::Class, :pop!
+      end
+
       # braced parts that aren't object literals
       state :statement do
         rule %r/case\b/ do
@@ -225,8 +261,6 @@ module Rouge
           groups Name::Label, Text, Punctuation
         end
 
-        rule %r/[{}]/, Punctuation
-
         mixin :expr_start
       end
 
@@ -265,9 +299,11 @@ module Rouge
 
       # template strings
       state :template_string do
-        rule %r/\${/, Punctuation, :template_string_expr
+        rule %r/[$]{/, Punctuation, :template_string_expr
         rule %r/`/, Str::Double, :pop!
-        rule %r/(\\\\|\\[\$`]|[^\$`]|\$(?!{))*/, Str::Double
+        rule %r/\\[$`\\]/, Str::Escape
+        rule %r/[^$`\\]+/, Str::Double
+        rule %r/[\\$]/, Str::Double
       end
 
       state :template_string_expr do
