@@ -37,14 +37,6 @@ module Rouge
         @builtins ||= %w()
       end
 
-      prepend :hash do
-        rule %r/[.,()*]/, Punctuation
-      end
-
-      prepend :array do
-        rule %r/[.,()*]/, Punctuation
-      end
-
       state :strings do
         rule %r/\\./, Str::Escape
         rule %r/\$\{/ do
@@ -81,9 +73,24 @@ module Rouge
         mixin :expression
       end
 
+      state :regexps do
+        rule %r/"\// do
+          token Str::Delimiter
+          goto :regexp_inner
+        end
+      end
+
+      state :regexp_inner do
+        rule %r/[^"\/\\]+/, Str::Regex
+        rule %r/\\./, Str::Regex
+        rule %r/\/"/, Str::Delimiter, :pop!
+        rule %r/["\/]/, Str::Regex
+      end
+
       id = /[$a-z_\-][a-z0-9_\-]*/io
 
       state :expression do
+        mixin :regexps
         mixin :primitives
         rule %r/\s+/, Text
 
